/*
// ----------------------------------------
// [common]
// ----------------------------------------
*  create by liangyong
*  公用方法
*  
*/

/**
 * 获取用户id
 */
var getUserId = function(){
	var userId = SyncManager.syncGetUserId()
	return userId;
}

/**
 * 获取用户类型
 */
var getUserType = function(){
	return SyncManager.syncGetUserType();
}

/**
 * 获取用户名
 */
var getUsername = function(){
	return SyncManager.syncGetUsername();
}

/**
 * 保存字符串到本地
 * @param {Object} cacheKey
 * @param {Object} value
 */
var saveLocalString = function(cacheKey, value){
	SyncManager.syncSetLocalStorage(cacheKey, value);
}

/**
 * 获取本地保存的字符串
 * @param {Object} cacheKey
 */
var getLocalString = function(cacheKey){
	return SyncManager.syncGetLocalStorage(cacheKey);
}

var setFPPraise = function(userId, footprintId){
	var cacheKey = userId + FOOTPRINT_PRAISE;
	pushItemToCacheArray(cacheKey, footprintId);
}

var isFPPraised = function(userId, footprintId){
	var cacheKey = userId + FOOTPRINT_PRAISE;
	var arr = getArrayFromCache(cacheKey);
	for(var i in arr)
	{
		if(footprintId == arr[i]){
			return true;
		}
	}
	return false;
}

var pushItemToCacheArray = function(cacheKey, value){
	var arr = getArrayFromCache(cacheKey);
	arr.push(value);
	saveLocalString(cacheKey, JSON.stringify(arr));
}

var getArrayFromCache = function(cacheKey){
	var arr = getLocalString(cacheKey);
	
	if(arr)
	{
		return JSON.parse(arr);
	}
	else
	{
		return [];
	}
}

/**
 * 问题点赞
 * @param {Object} userId
 * @param {Object} questionId
 */
var setReplyUp = function(userId, replyId){
	var cacheKey = userId + REPLY_OPERATION;
	setArrayItemToCache(cacheKey, replyId, 1);
}

/**
 * 问题点踩
 * @param {Object} userId
 * @param {Object} questionId
 */
var setReplyDown = function(userId, replyId){
	var cacheKey = userId + REPLY_OPERATION;
	setArrayItemToCache(cacheKey, replyId, 2);
}

/**
 * 取消问题回复点赞或踩操作
 * @param {Object} userId
 * @param {Object} questionId
 */
var cancelReplyOperation = function(userId, replyId){
	var cacheKey = userId + REPLY_OPERATION;
	setArrayItemToCache(cacheKey, replyId, 0);
}

var getReplyOperation = function(userId, replyId){
	var cacheKey = userId + REPLY_OPERATION;
	var arr = getObjectFromCache(cacheKey);
	if(arr[replyId])
	{
		return arr[replyId];
	}
	else
	{
		return 0;
	}
}

/**
 * 问题的回复是否点过赞或踩     1表示操作过  0表示没操作过
 * @param {Object} userId
 * @param {Object} questionId
 */

var isReplyOperated = function(userId, replyId){
	var cacheKey = userId + REPLY_OPERATION;
	var arr = getObjectFromCache(cacheKey);
	if(arr[replyId] || arr[replyId] == 0 || arr[replyId] == "0")
	{
		return 1
	}
	else
	{
		return 0;
	}
}

/**
 * key所保存的字典数据中，添加或覆盖一项
 * @param {Object} key
 * @param {Object} value
 */
var setArrayItemToCache = function(cacheKey, itemKey, value){
	var arr = getObjectFromCache(cacheKey);
	arr[itemKey] = value
	saveLocalString(cacheKey, JSON.stringify(arr));
}

/**
 * 通过key获取本地字典数据
 * @param {Object} cacheKey
 */

var getObjectFromCache = function(cacheKey){
	var arr = getLocalString(cacheKey);
	
	if(arr)
	{
		return JSON.parse(arr);
	}
	else
	{
		return {};
	}
}
//乘法函数，用来得到精确的乘法结果 
//说明：javascript的乘法结果会有误差，在两个浮点数相乘的时候会比较明显。这个函数返回较为精确的乘法结果。 
//调用：accMul(arg1,arg2) 
//返回值：arg1乘以arg2的精确结果 
var accMul = function(arg1,arg2) 
{ 
    var m=0,s1=arg1.toString(),s2=arg2.toString(); 
    try{m+=s1.split(".")[1].length}catch(e){} 
    try{m+=s2.split(".")[1].length}catch(e){} 
    return Number(s1.replace(".",""))*Number(s2.replace(".",""))/Math.pow(10,m) 
} 
//获取时间--xx天、小时、分、秒前
function getDaysBefore(timeStr){
	var myDate = new Date();
	var nowTime = myDate.getTime(); 
	
	var newTimeStr = timeStr.replace(/-/g, "/");
	var publishTime = new Date(newTimeStr).getTime(); 

	var endTime = parseInt((nowTime - publishTime) / 1000 );
	var m =	parseInt(endTime / 60);
	var h = parseInt(endTime / 3600);
	var d = parseInt(endTime/3600/24)
	if(m < 60){
		if(m == 0)
		{
			return "1分钟前";
		}
		return m + "分钟前";
	}else if(h < 24){
		return h + "小时前";
	}else if(d >= 1){
		return d + "天前";
	}
}
