/**
 * 本地数据常量
 */
const REPLY_OPERATION = "REPLY_OPERATION";//问题回复操作,0:未操作，1：点赞，2：点踩
const USER_INFO = "userInfo";//本地保存的个人信息
const FOOTPRINT_PRAISE = "FOOTPRINT_PRAISE";//保存足迹的id，有id表示点过赞
/**
 * 获取用户id
 */
function getUserId(){
	var userId = SyncManager.syncGetUserId()
	return userId;
}
/**
 * 获取用户类型
 */
function getUserType(){
	return SyncManager.syncGetUserType();
}
/**
 * 保存字符串到本地
 * @param {Object} cacheKey
 * @param {Object} value
 */
function saveLocalString(cacheKey, value)
{
	SyncManager.syncSetLocalStorage(cacheKey, value);
}
/**
 * 获取本地保存的字符串
 * @param {Object} cacheKey
 */
function getLocalString(cacheKey){
	return SyncManager.syncGetLocalStorage(cacheKey);
}

function setFPPraise(userId, footprintId)
{
	var cacheKey = userId + FOOTPRINT_PRAISE;
	pushItemToCacheArray(cacheKey, footprintId)
}
function isFPPraised(userId, footprintId)
{
	var cacheKey = userId + FOOTPRINT_PRAISE;
	var arr = getArrayFromCache(cacheKey);
	for(var i in arr)
	{
		if(footprintId == arr[i]){
			return true;
		}
	}
	return false;
}
function pushItemToCacheArray(cacheKey, value)
{
	var arr = getArrayFromCache(cacheKey);
	arr.push(value);
	saveLocalString(cacheKey, JSON.stringify(arr));
}
function getArrayFromCache(cacheKey)
{
	var arr = getLocalString(cacheKey);
	
	if(arr)
	{
		return JSON.parse(arr);
	}
	else
	{
		return [];
	}
}
/**
 * 问题点赞
 * @param {Object} userId
 * @param {Object} questionId
 */
function setReplyUp(userId, replyId)
{
	var cacheKey = userId + REPLY_OPERATION;
	setArrayItemToCache(cacheKey, replyId, 1);
}
/**
 * 问题点踩
 * @param {Object} userId
 * @param {Object} questionId
 */
function setReplyDown(userId, replyId)
{
	var cacheKey = userId + REPLY_OPERATION;
	setArrayItemToCache(cacheKey, replyId, 2);
}
/**
 * 取消问题回复点赞或踩操作
 * @param {Object} userId
 * @param {Object} questionId
 */
function cancelReplyOperation(userId, replyId)
{
	var cacheKey = userId + REPLY_OPERATION;
	setArrayItemToCache(cacheKey, replyId, 0);
}
function getReplyOperation(userId, replyId)
{
	var cacheKey = userId + REPLY_OPERATION;
	var arr = getObjectFromCache(cacheKey);
	if(arr[replyId])
	{
		return arr[replyId];
	}
	else
	{
		return 0;
	}
}
/**
 * 问题的回复是否点过赞或踩     1表示操作过  0表示没操作过
 * @param {Object} userId
 * @param {Object} questionId
 */
function isReplyOperated(userId, replyId)
{
	var cacheKey = userId + REPLY_OPERATION;
	var arr = getObjectFromCache(cacheKey);
	if(arr[replyId] || arr[replyId] == 0 || arr[replyId] == "0")
	{
		return 1
	}
	else
	{
		return 0;
	}
}
/**
 * key所保存的字典数据中，添加或覆盖一项
 * @param {Object} key
 * @param {Object} value
 */
function setArrayItemToCache(cacheKey, itemKey, value)
{
	var arr = getObjectFromCache(cacheKey);
	arr[itemKey] = value
	saveLocalString(cacheKey, JSON.stringify(arr));
}
/**
 * 通过key获取本地字典数据
 * @param {Object} cacheKey
 */
function getObjectFromCache(cacheKey)
{
	var arr = getLocalString(cacheKey);
	
	if(arr)
	{
		return JSON.parse(arr);
	}
	else
	{
		return {};
	}
}
